@@ -655,7 +655,7 @@ sub resolve_sockaddr($$$$$$) {
    $proto ||= "tcp";
    $type  ||= $proto eq "udp" ? SOCK_DGRAM : SOCK_STREAM;
 
-   my $proton = getprotobyname $proto
+   my $proton = AnyEvent::Socket::getprotobyname $proto
       or Carp::croak "$proto: protocol unknown";
 
    my $port;
@@ -799,8 +799,10 @@ The file handle is perfect for being plugged into L<AnyEvent::Handle>, but
 can be used as a normal perl file handle as well.
 
 Unless called in void context, C<tcp_connect> returns a guard object that
-will automatically abort connecting when it gets destroyed (it does not do
-anything to the socket after the connect was successful).
+will automatically cancel the connection attempt when it gets destroyed
+- in which case the callback will not be invoked. Destroying it does not
+do anything to the socket after the connect was successful - you cannot
+"uncall" a callback that has been invoked already.
 
 Sometimes you need to "prepare" the socket before connecting, for example,
 to C<bind> it to some port, or you want a specific connect timeout that
@@ -896,7 +898,11 @@ sub tcp_connect($$$;$) {
          return unless exists $state{fh};
 
          my $target = shift @target
-            or return (%state = (), _postpone $connect);
+            or return _postpone sub {
+               return unless exists $state{fh};
+               %state = ();
+               $connect->();
+            };
 
          my ($domain, $type, $proto, $sockaddr) = @$target;
 
@@ -1106,6 +1112,35 @@ sub tcp_server($$$;$) {
       : ()
 }
 
+=item tcp_nodelay $fh, $enable
+
+Enables (or disables) the C<TCP_NODELAY> socket option (also known as
+Nagle's algorithm). Returns false on error, true otherwise.
+
+=cut
+
+sub tcp_nodelay($$) {
+   my $onoff = int ! ! $_[1];
+
+   setsockopt $_[0], Socket::IPPROTO_TCP (), Socket::TCP_NODELAY (), $onoff
+}
+
+=item tcp_congestion $fh, $algorithm
+
+Sets the tcp congestion avoidance algorithm (via the C<TCP_CONGESTION>
+socket option). The default is OS-specific, but is usually
+C<reno>. Typical other available choices include C<cubic>, C<lp>, C<bic>,
+C<highspeed>, C<htcp>, C<hybla>, C<illinois>, C<scalable>, C<vegas>,
+C<veno>, C<westwood> and C<yeah>.
+
+=cut
+
+sub tcp_congestion($$) {
+   defined TCP_CONGESTION
+      ? setsockopt $_[0], Socket::IPPROTO_TCP (), TCP_CONGESTION, "$_[1]"
+      : undef
+}
+
 1;
 
 =back
